@@ -57,11 +57,19 @@ vpc_saemFit = function(fit, dat, nsim = 100, by=NULL, ...) {
   xs = do.call("cbind",s)
   df = cbind(xd[ord, c("ID", "TIME", "grp")], DV=as.vector(xs), SIM=sim)
 
-  if (!is.null(by)) {
-      p = vpc::vpc(sim = df, obs = dat, strat=c("grp"), facet="wrap", ...)
+  ns <- loadNamespace("vpc");
+  if (exists("vpc_vpc",ns)){
+      vpcn <- "vpc_vpc"
   } else {
-      p = vpc::vpc(sim = df, obs = dat, ...)
+      vpcn <- "vpc"
   }
+  call <- as.list(match.call(expand.dots=TRUE))[-1];
+  if (!is.null(by)) {
+      call$strat <- c("grp")
+      call$facet <- "wrap";
+  }
+  call <- call[names(call) %in% methods::formalArgs(getFromNamespace(vpcn,"vpc"))]
+  p = do.call(getFromNamespace(vpcn,"vpc"), c(list(sim=df, obs=dat), call), envir = parent.frame(1))
   print(p)
 
   invisible(df)
